Taly.Field (taly v0.1.2)
Create the field of schema or schema option.
Schema options
These are the schema options.
:type- the type of the option item.:required- the option tiem is required.:default- the default value for option item if not specified.:subtype- the option item if you validate the list-data.:form- supper to validate the value that is a dict-type.:action- a function that output data:format- the data type date or datetime format-string
Types
:any- Any type:str- String:int- Integer:float- Float:atom- Atom:bool- Boolean:list- List:dict- Map or Keyword:map- Map:keyword- Keyword:date- Date, default format-string is "{YYYY}/{0M}/{D}":datetime- all Datetime type, default format-string is "%F %T"
Link to this section Summary
Link to this section Functions
Link to this function
field(name, opt \\ [], contents \\ [])
Link to this function